# Maginner
Easily create a banner to level up your program

---
---
## Use
---
This program is intended to help developers of command line utilities to beautify their tool by adding a Banner.

> import maginner as mg
>> mg.maginner("TOOL_NAME")

---
---
### Considerations 
---
Supported characters
```
- Alphabetic characters [A-Z]
- Blank spaces (' ')
- Dot ('.')
```

